@@ -451,15 +451,19 @@ def apply_packaged_translation(
     info("sentences", sentences)
 
     # Tokenization
-    sp_model_path = str(pkg.package_path / "sentencepiece.model")
-    sp_processor = spm.SentencePieceProcessor(model_file=sp_model_path)
-    tokenized = [sp_processor.encode(sentence, out_type=str) for sentence in sentences]
+    tokenized = [pkg.tokenizer.encode(sentence) for sentence in sentences]
     info("tokenized", tokenized)
 
     # Translation
     BATCH_SIZE = 32
+    target_prefix = None
+
+    if pkg.target_prefix != "":
+        target_prefix = [[pkg.target_prefix]] * len(tokenized)
+
     translated_batches = translator.translate_batch(
         tokenized,
+        target_prefix=target_prefix,
         replace_unknowns=True,
         max_batch_size=BATCH_SIZE,
         beam_size=max(num_hypotheses, 4),
@@ -477,13 +481,18 @@ def apply_packaged_translation(
         for translated_batch in translated_batches:
             translated_tokens += translated_batch[i]["tokens"]
             cumulative_score += translated_batch[i]["score"]
-        detokenized = "".join(translated_tokens)
-        detokenized = detokenized.replace("▁", " ")
-        value = detokenized
+        
+        value = pkg.tokenizer.decode(translated_tokens)
+        
+        if pkg.target_prefix != "" and value.startswith(pkg.target_prefix):
+            # Remove target prefix
+            value = value[len(pkg.target_prefix):]
+
         if len(value) > 0 and value[0] == " ":
             # Remove space at the beginning of the translation added
             # by the tokenizer.
             value = value[1:]
+        
         hypothesis = Hypothesis(value, cumulative_score)
         value_hypotheses.append(hypothesis)
     info("value_hypotheses:", value_hypotheses)
